from .Router import Router


class EventTypeRouter(Router):
    pass
